@@ -1,6 +1,6 @@
 #!/usr/bin/wish -f
 #
-# $Id: TdDebug.tcl,v 5.5 1998/02/20 13:55:43 daved Exp $
+# $Id: TdDebug.tcl,v 5.11 2001/08/17 18:56:13 daved Exp $
 #
 # tdebug.tcl - A simple debugger for tcl scripts
 # Version 1.1
@@ -74,6 +74,9 @@ foreach i "\
 	{useblt		        [expr \"[info command blt_busy]\" == \
 				\"blt_busy\"] \
 					0} \
+	{usetix		        [expr \"[info command tix]\" == \
+				\"tix\"] \
+					0} \
 	{preparedtag 		{-background [lindex [.td_dummy configure\
 				-activebackground] 4]} NOCHECK} \
 	{activetag              {-background orange -relief raised \
@@ -519,7 +522,7 @@ proc td_eval {name l1 l2 script} {
     }
 	
     # pop up debugger window
-    if {[wm state $td_Top] != "normal"} {
+    if {[winfo exists $td_Top] && [wm state $td_Top] != "normal"} {
 	wm deiconify $td_Top
 	raise $td_Top
     }
@@ -1720,17 +1723,29 @@ bind $td_Top <Control-a> {$td_MenuVars invoke 1}
 # }}}
 # {{{ the main region
 
-frame $td_MainRegion
-pack $td_MainRegion -side top -expand 1 -fill both
+if { $td_priv(usetix) } {
+    tixPanedWindow $td_MainRegion -orient horizontal
 
+    $td_MainRegion add mainFrame -size 500
+    $td_MainRegion add varFrame -size [expr $td_priv(varwidth) * 5 ]
+    pack $td_MainRegion -side top -expand 1 -fill both
+ 
+    frame $td_ListFrame -borderwidth 2 -relief raised
+    pack $td_ListFrame -side top -expand 1 -fill both -padx 2 -pady 2 -in $td_MainFrame
+   
+} else {
+    frame $td_MainRegion
+    pack $td_MainRegion -side top -expand 1 -fill both
+
+    frame $td_MainFrame
+    pack $td_MainFrame -side left -expand 1 -fill both
+
+    frame $td_ListFrame -borderwidth 2 -relief raised
+    pack $td_ListFrame -side top -expand 1 -fill both -padx 2 -pady 2 
+
+}
 # {{{ the listing
 
-frame $td_MainFrame
-pack $td_MainFrame -side left -expand 1 -fill both
-
-frame $td_ListFrame -borderwidth 2 -relief raised
-pack $td_ListFrame -side top -expand 1 -fill both -padx 2 -pady 2
-
 frame $td_ListNameFrame -relief raised -borderwidth 0
 pack $td_ListNameFrame -side top -fill x
 label $td_ListName -text "Proc  :" -borderwidth 0 -width 8
@@ -1792,8 +1807,12 @@ bind $td_Listing <Double-Button-1> "td_setBreakpoint %x %y"
 # }}}
 # {{{ the variables
 
-frame $td_VarFrame
-pack $td_VarFrame -side left -fill both 
+if { $td_priv(usetix) } {
+    # Defined above 
+} else {
+    frame $td_VarFrame
+    pack $td_VarFrame -side left -fill both 
+}
 
 frame $td_VarFrame1 -borderwidth 2 -relief raised
 pack $td_VarFrame1 -side top -fill both -expand 1 -padx 2 -pady 2
@@ -1846,6 +1865,10 @@ pack $td_VarScrollX -side $td_priv(scrollbarside) -expand 1 -fill x
 
 # }}}
 
+if { $td_priv(usetix) } {
+    pack $td_MainRegion -side top -expand 1 -fill both
+}
+
 # }}}
 # {{{ the result
 
